# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.response_wrapper_chat_message_read_with_metadata import ResponseWrapperChatMessageReadWithMetadata

class TestResponseWrapperChatMessageReadWithMetadata(unittest.TestCase):
    """ResponseWrapperChatMessageReadWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatMessageReadWithMetadata:
        """Test ResponseWrapperChatMessageReadWithMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatMessageReadWithMetadata`
        """
        model = ResponseWrapperChatMessageReadWithMetadata()
        if include_optional:
            return ResponseWrapperChatMessageReadWithMetadata(
                done = True,
                result = chat_server_connector_v2.models.chat_message_read_with_metadata.ChatMessageReadWithMetadata(
                    text = '', 
                    file_id = '', 
                    id = 56, 
                    chat_message_type = 'TEXT', 
                    run_id = '', 
                    chat_id = 56, 
                    chat_member_id = 56, 
                    added_at = 56, 
                    attachments = [
                        chat_server_connector_v2.models.chat_message_attachment_read_with_metadata.ChatMessageAttachmentReadWithMetadata(
                            file_id = '', 
                            attachment_type = 'IMAGE', 
                            id = 56, 
                            file_url = '', 
                            full_file_name = '', 
                            file_size = 56, 
                            file_extension = '', 
                            mime_type = '', )
                        ], 
                    chat_session = chat_server_connector_v2.models.chat_session_get.ChatSessionGet(
                        id = 56, 
                        chat_id = 56, 
                        creator_id = 56, 
                        credentials = chat_server_connector_v2.models.credentials.Credentials(), 
                        chat_session_type = 'TEXT', 
                        created_at = 56, 
                        ended_at = 56, 
                        last_activity_at = 56, ), 
                    usage = chat_server_connector_v2.models.session_usage.SessionUsage(
                        total_mentorcoin = 1.337, 
                        by_type = [
                            chat_server_connector_v2.models.usage_by_type.UsageByType(
                                type = 'text', 
                                mentorcoin = 1.337, )
                            ], ), 
                    feedback = chat_server_connector_v2.models.feedback_read.FeedbackRead(
                        id = 56, 
                        chat_session_id = 56, 
                        chat_member_id = 56, 
                        type = 'BUG', 
                        text = '', 
                        priority = 56, 
                        added_at = 56, 
                        updated_at = 56, ), ),
                error = ''
            )
        else:
            return ResponseWrapperChatMessageReadWithMetadata(
                done = True,
        )
        """

    def testResponseWrapperChatMessageReadWithMetadata(self):
        """Test ResponseWrapperChatMessageReadWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
